# package information.
INFO = dict(
    name="Mew Calc",
    description="The calculator fot cat's age",
    author="shinriyo",
    author_email="shinriyo@gmail.com",
    license="MIT License",
    url="https://github.com/shinriyo/cat_age_calculator",
    classifiers=[
        "Programming Language :: Python :: 2.7",
        "License :: OSI Approved :: MIT License"
    ]
)

from .port_killer import nothing



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys
import socket
# import subprocess
import re

def check_port(port_num):
    """
    ポートを調べる
    :return: ポートが使われてなければTrueで使われてたらFalse
    """
    # print('check_port')
    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    result = sock.connect_ex(('127.0.0.1', port_num))

    if result == 0:
        # print("ポート %d は使用しています。" % port_num)
        print("The port %d is using." % port_num)
        return False
    else:
        # print("ポート %d は使用していません。" % port_num)
        sys.exit("The port %d is not used." % port_num)
        return True # ここは通らないけど

LINUX = 0
MAC = 1
WINDOWS = 2
OTHER = 3

def get_os():
    from sys import platform as _platform
    if _platform in ["linux", "linux2"]:
        return LINUX
    elif _platform == "darwin":
        return MAC
    elif _platform == "win32":
        return WINDOWS
    else:
        return OTHER

def get_killable_process(port_num):
    """
    ポートに対して殺せるプロセス番号を得る
    :param port_num:
    :return: プロセスの番号、なければ空文字
    """
    txt_file_name = "net.txt"
    # Linux
    if get_os() == LINUX:
        os.system("netstat -anp | grep %d > %s" % (port_num, txt_file_name))
    # Mac OS
    elif get_os() == MAC:
        os.system("lsof -n -P -i :%d | grep %d > %s" % (port_num, port_num, txt_file_name))
    # Windows
    elif get_os() == WINDOWS:
        sys.exit('Windows OS is not supported.')
    else:
        sys.exit('unknown OS is not supported.')

    f = open(txt_file_name, "r")
    # 1行毎にファイル終端まで全て読む(改行文字も含まれる)
    lines = f.readlines()
    f.close()

    killable_process = ''

    for line in lines:
        # 犯人
        # Linux
        # res = re.search('(\d+)(?=/.*)', line)
        # Mac
        # python  25462 shinriyo    5u  IPv4 0x69c76ff36ff53e9b      0t0  TCP *:5000 (LISTEN)
        res = re.search('(\d+)', line)
        # 正規表現に引っかからなかったらNoneなのでそれを弾く
        if res != None:
            # net.txt削除
            # f = open(txt_file_name, "r")
            print res.group()
            killable_process = res.group()
            print 'killable process: %s' % killable_process

    return killable_process

if __name__ == "__main__":
    argvs = sys.argv  # コマンドライン引数を格納したリストの取得
    argc = len(argvs) # 引数の個数
    port_num = 8080

    # 引数が1つなのは自分自身の.py
    if (argc == 1):
        pass
    elif (argc == 2):
        arg_port = argvs[1]
        # 整数の時だけ
        try:
            int(arg_port, 10)
        except:
            sys.exit('Port number is not number.')
        else: # success
            port_num = int(arg_port)
    else:
        sys.exit('Argments are invalid.')

    # ポート名をセット
    # ポートが-1でなくなおかつファイルが存在するかをチェックする
    if port_num != -1 and True:
        if check_port(port_num):
           # 使っているportでのプロセスはないです。
            sys.exit('The process of the port number does not exist.')
        else:
            # killすべきプロセス
            killable_process = get_killable_process(port_num)
            if killable_process != '':
                # name = raw_input('プロセス%sをkillしますか？ [y/n]' % killable_process)
                name = raw_input('Do you kill the process %s? [y/n]' % killable_process)
                if name == 'y':
                    os.kill(int(killable_process), 9)
                else:
                    print 'Successly stopped'
                    sys.exit()
            else:
                # Processをkillできなかった
                sys.exit('can\'t killed the process.')
    else:
        # 実行出来ませんでした。
        sys.exit('Killing process failed.')




#!/usr/bin/env python
# -*- coding:utf-8 -*-

try:
    import setuptools
    from setuptools import setup, find_packages
except ImportError:
    print("Please install setuptools.")


def find_scripts(scripts_path):
     base_path = os.path.abspath(scripts_path)
     return list(map(lambda path: os.path.join(scripts_path, path),
          filter(lambda file_name: os.path.isfile(
          os.path.join(base_path, file_name)),
          os.listdir(base_path)
     )))

import os
import sys

libdir = "lib/port_killer"
bindir = os.path.join(libdir, "bin")

sys.path.insert(0, libdir)

import info
import version

setup_options = info.INFO
setup_options["version"] = version.VERSION
setup_options.update(dict(
  #install_requires = open('requirements.txt').read().splitlines(),
  scripts          = find_scripts(bindir),
  packages         = find_packages(libdir),
  package_dir      = {"": libdir},
))

setup(**setup_options)



# package information.
INFO = dict(
  name        = "port_killer",
  description = "It kills process by specify port number.",
  author      = "shinriyo",
  author_email = "shinriyo@gmail.com",
  license     = "MIT License",
  url         = "https://github.com/shinriyo/port_killer",
  classifiers = [
    "Programming Language :: Python :: 2.7",
    "License :: OSI Approved :: MIT License"
  ]
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import random
import unittest
from lib.port_killer.port_killer import nothing

from datetime import datetime, date, time


class PortKillerTest(unittest.TestCase):
    def setUp(self):
        pass

    def test_port(self):
        """
        """
        self.assertEqual(True, True)


if __name__ == '__main__':
    unittest.main()
